@@ -6,6 +6,16 @@ import xarray as xr
 from numpy.lib.recfunctions import rename_fields as np_rename_fields
 
 
+def nc_vars(filename):
+    with nc.Dataset(filename, "r") as rgrp:
+        attrs = rgrp.__dict__
+
+        tiles = list(rgrp.groups)
+        nc_variables = list(rgrp[tiles[0]].variables)
+
+    return nc_variables
+
+
 def nc2xr(filename, vars=None, chunk_size=10):
 
     with nc.Dataset(filename, "r") as rgrp:
